@@ -2,7 +2,7 @@ from jh_utils.data.pandas import sql
 import dask as dd
 
 def migrate_table_pandas(query, table_name, engine_origin, engine_destiny, destiny_schema, if_exists):
-    df = sql.get_data(query, engine_origin)
+    df = sql.get_sql_table(query, engine_origin)
     sql.write_table(df, table_name, destiny_schema, engine_destiny,
                     if_exists=if_exists, chunksize=10_000, index=False, close_connection=False)
 
@@ -10,7 +10,7 @@ def migrate_function_pandas(engine_origin,
                          engine_destiny, 
                          destiny_schema,index=False):
     def output_func(query, table_name, if_exists='replace', chunksize=10_000):
-        df = sql.get_data(query, engine_origin)
+        df = sql.get_sql_table(query, engine_origin)
         sql.write_table(df, table_name, destiny_schema, engine_destiny,
                         if_exists=if_exists, chunksize=10_000, 
                         index=False, close_connection=False)
